@@ -4,7 +4,7 @@ import gobject
 import sys
 
 from telepathy.constants import (
-    CONNECTION_STATUS_CONNECTED, CONNECTION_STATUS_DISCONNECTED
+    CONNECTION_STATUS_CONNECTED, CONNECTION_STATUS_DISCONNECTED)
 from telepathy.interfaces import (
     CONN_INTERFACE, CONN_INTERFACE_AVATARS)
 
@@ -14,30 +14,32 @@ registered = False
 loop = None
 
 def status_changed_cb(state, reason):
-    print 'status changed', state
+    global registered
 
     if state == CONNECTION_STATUS_CONNECTED:
         print 'registered'
         registered = True
-        conn.Disconnect()
+        conn[CONN_INTERFACE].Disconnect()
     elif state == CONNECTION_STATUS_DISCONNECTED:
-        if !registered:
+        if not registered:
             print 'failed'
 
-    loop.quit()
+        loop.quit()
 
 if __name__ == '__main__':
     manager, protocol, account = read_account(sys.argv[1])
     account['register'] = True
     conn = connect(manager, protocol, account)
-
-    # XXX: hack!
-    conn._valid_interfaces = [CONN_INTERFACE]
     conn[CONN_INTERFACE].connect_to_signal('StatusChanged', status_changed_cb)
 
     print 'connecting'
     conn[CONN_INTERFACE].Connect()
     loop = gobject.MainLoop()
     loop.run()
-    conn[CONN_INTERFACE].Disconnect()
+
+    try:
+        conn[CONN_INTERFACE].Disconnect()
+    except:
+        pass
+
 
